@@ -27,8 +27,8 @@ Q_OBJECT
 		void deleteMe();
 
 	protected:
-		void mousePressEvent(QMouseEvent *);
-		bool eventFilter(QObject *obj, QEvent *ev);
+		void mousePressEvent(QMouseEvent *) override;
+		bool eventFilter(QObject *obj, QEvent *ev) override;
 
 	private:
 		QString wikipedia;
