@@ -50,13 +50,13 @@ Q_OBJECT
 		void clicked(QRgb, const QPoint&, const QPointF &);
 	
 	protected:
-		void mousePressEvent(QMouseEvent *e);
-		void mouseMoveEvent(QMouseEvent *e);
-		void mouseReleaseEvent(QMouseEvent *e);
-		void enterEvent(QEvent *e);
-		void leaveEvent(QEvent *e);
-		void wheelEvent(QWheelEvent *e);
-		void resizeEvent(QResizeEvent *e);
+		void mousePressEvent(QMouseEvent *e) override;
+		void mouseMoveEvent(QMouseEvent *e) override;
+		void mouseReleaseEvent(QMouseEvent *e) override;
+		void enterEvent(QEvent *e) override;
+		void leaveEvent(QEvent *e) override;
+		void wheelEvent(QWheelEvent *e) override;
+		void resizeEvent(QResizeEvent *e) override;
 		void createGameMapImage();
 		void updateCursor();
 
